@@ -293,6 +293,7 @@ testPlots <- function() {
     graphics::plot(df$value.x ~ df$value.y, col = factor(df$variable))
   }
   assign("plotMultiTestMf", plotMultiTestMf, envir = parent.frame())
+
   multiModel_scatterplot <- function(x) {
     ggdf <- data.frame(
       var1 = x[[1]]$results[,"beta"],
@@ -313,6 +314,17 @@ testPlots <- function() {
   }
   assign("multiModel_barplot_sf", multiModel_barplot_sf, envir = parent.frame())
 
+  plotPlotly <- function(x){
+    plotPoints <- as.numeric(x[["assays"]][1, ])
+    featureMedian <- stats::median(plotPoints)
+    plotTitle <- sprintf("%s, median: %0.2f", x[["features"]][["customID"]],
+                         featureMedian)
+    p <- ggplot2::qplot(seq_along(plotPoints), plotPoints, main = plotTitle,
+                   xlab = "Samples", ylab = "Expression level")
+    plotly::ggplotly(p)
+  }
+  assign("plotPlotly", plotPlotly, envir = parent.frame())
+
   plots <- list(
     default = list(
       plotBase = list(
@@ -351,6 +363,11 @@ testPlots <- function() {
         displayName = "Custom ggplot2 plot",
         plotType = "singleFeature",
         packages = c("ggplot2", "stats")
+      ),
+      plotPlotly = list(
+        displayName = "Custom plotly plot",
+        plotType = c("singleFeature", "plotly"),
+        packages = c("plotly", "ggplot2", "stats")
       )
     )
   )
