@@ -2,14 +2,19 @@
 #'
 #' @name shared-upset
 #'
-#' @param anchor The primary test to filter from.
-#' @param mustTests The tests whose significant values must be included. (The intersection)
-#' @param notTests The tests whose significant values will be removed. (The difference)
-#' @param sigValue The significance levels for each column.
-#' @param operator The operators for each column.
-#' @param column The columns to be thresheld.
-#' @param type Type of p-value (\code{"nominal"} or \code{"adjusted"})
-#' @param tests Restrict UpSet plot to these tests
+#' @param anchor The primary testID to filter the results
+#' @param mustTests The testIDs for which a featureID (or termID for enrichment)
+#'   must pass the filters
+#' @param notTests The testIDs for which a featureID (or termID for enrichment)
+#'   must \bold{not} pass the filters. In other words, if a featureID passes the
+#'   filter for a testID specified in notTests, that featureID is removed from
+#'   the output
+#' @param sigValue The numeric significance value to use as a cutoff for each
+#'   column
+#' @param operator The comparison operators for each column, e.g. \code{"<"}
+#' @param column The columns to apply the filters
+#' @param type Type of p-value: (\code{"nominal"} or \code{"adjusted"})
+#' @param tests Restrict UpSet plot to only include these tests
 #' @param legacy Use legacy code (for testing purposes only)
 #'
 #' @keywords internal
@@ -88,7 +93,15 @@ getResultsIntersection <- function(
 #'
 #' @return a table
 #' @examples
-#'  getInferenceIntersection(testCategory = "No Pretreatment Timecourse Differential Phosphorylation", sigValue = c(.05,.01), notTests=c(), anchor = "IKE", mustTests = c("FIN56"), operator = c("<",">"), column = c("adj_P_Val","adj_P_Val"))
+#'  getInferenceIntersection(
+#'    testCategory = "No Pretreatment Timecourse Differential Phosphorylation",
+#'    sigValue = c(.05, .01),
+#'    notTests = c(),
+#'    anchor = "IKE",
+#'    mustTests = c("FIN56"),
+#'    operator = c("<", ">"),
+#'    column = c("adj_P_Val", "adj_P_Val")
+#'  )
 #'
 #' Changes made to original function:
 #'   * Added Inference.Results as first argument
@@ -96,62 +109,80 @@ getResultsIntersection <- function(
 #'   * Changed `<=` and `>=` to `<` and `>`, respectively, to match app UI
 #'   * Reordered `anchor` test to start of tests using `union()`
 #' @noRd
-getInferenceIntersection <- function(Inference.Results, testCategory, anchor, mustTests, notTests, sigValue, operator=c("<"), column=c("adj_P_Val")) {
-
-  #Initializing the master data frame to the anchor
+getInferenceIntersection <- function(
+  Inference.Results,
+  testCategory,
+  anchor,
+  mustTests,
+  notTests,
+  sigValue,
+  operator = c("<"),
+  column = c("adj_P_Val")
+)
+{
+  # Initializing the master data frame to the anchor
   rv <- Inference.Results[[testCategory]][[anchor]]
 
   if (length(sigValue) != length(operator) || length(column) != length(operator)) {
     stop("The arguments sigValue, column, and operator must be the same length")
   }
 
-  #Instantiate the set membership column. This will be filled out as you go. If the protein site is significant
-  #in the study, then it will concatenate the study to the set membership column.
+  # Instantiate the set membership column. This will be filled out as you go. If
+  # the protein site is significant in the study, then it will concatenate the
+  # study to the set membership column.
   rv$Set_Membership <- anchor
   tests <- names(Inference.Results[[testCategory]])
   tests <- union(anchor, tests)
 
-  #Calculate Intersection
-  for(i in 1:length(tests)){
+  # Calculate Intersection
+  for (i in 1:length(tests)) {
     isNotTest <- tests[i] %in% notTests
-    temp = Inference.Results[[testCategory]][[tests[i]]]
+    temp <- Inference.Results[[testCategory]][[tests[i]]]
     id <- colnames(temp)[1]
-    fTemp = data.frame(temp[,id])
+    fTemp <- data.frame(temp[, id])
     if (isNotTest) {
-      fTemp = cbind(fTemp, 0)
+      fTemp <- cbind(fTemp, 0)
     } else {
-      fTemp = cbind(fTemp, 1)
+      fTemp <- cbind(fTemp, 1)
     }
-    for(k in 1:length(operator)){
-      sigCol = c(temp[,column[k]])
-      if(operator[k] == "<"){sigCol <- as.numeric(sigCol < sigValue[k])}
-      else if(operator[k] == ">"){sigCol <- as.numeric(sigCol > sigValue[k])}
-      else if(operator[k] == "|>|"){sigCol <- as.numeric(abs(sigCol) > sigValue[k])}
-      else if(operator[k] == "|<|"){sigCol <- as.numeric(abs(sigCol) < sigValue[k])}
-      if(isNotTest) {
+    for (k in 1:length(operator)) {
+      sigCol <- c(temp[, column[k]])
+      if (operator[k] == "<") {
+        sigCol <- as.numeric(sigCol < sigValue[k])
+      } else if (operator[k] == ">") {
+        sigCol <- as.numeric(sigCol > sigValue[k])
+      } else if (operator[k] == "|>|") {
+        sigCol <- as.numeric(abs(sigCol) > sigValue[k])
+      } else if (operator[k] == "|<|") {
+        sigCol <- as.numeric(abs(sigCol) < sigValue[k])
+      }
+      if (isNotTest) {
         # notTests should "pass" if they meet any of the filters. That way when
         # they are filtered out below, any featureID that meets any of the
         # filters is removed from the final results.
-        fTemp[,2] = as.integer(fTemp[,2] | sigCol)
+        fTemp[, 2] <- as.integer(fTemp[, 2] | sigCol)
       } else {
-        fTemp[,2] = as.integer(fTemp[,2] & sigCol)
+        fTemp[, 2] <- as.integer(fTemp[, 2] & sigCol)
       }
     }
-    fTemp = fTemp[fTemp[,2] == 1,]
-    temp = temp[temp[,id] %in% fTemp[,1],]
-    if(tests[i] %in% mustTests || tests[i] == anchor){
-      rv = rv[rv[,id] %in% temp[,id],]
-      if(nrow(rv) == 0){return(rv)}
-      if(tests[i] != anchor){rv$Set_Membership <- paste(rv$Set_Membership, tests[i], sep = " , ")}
+    fTemp <- fTemp[fTemp[, 2] == 1, ]
+    temp <- temp[temp[, id] %in% fTemp[, 1], ]
+    if (tests[i] %in% mustTests || tests[i] == anchor) {
+      rv <- rv[rv[, id] %in% temp[, id], ]
+      if (nrow(rv) == 0) {return(rv)}
+      if (tests[i] != anchor) {
+        rv$Set_Membership <- paste(rv$Set_Membership, tests[i], sep = " , ")
+      }
+    } else if (tests[i] %in% notTests) {
+      rv <- rv[!rv[, id] %in% temp[, id], ]
+      if (nrow(rv) == 0) {return(rv)}
+    } else {
+      rv[which(is.element(rv$id, temp[, id])), "Set_Membership"] <-
+        paste(rv[which(is.element(rv$id, temp[, id])), "Set_Membership"], tests[i], sep = " , ")
     }
-    else if(tests[i] %in% notTests){
-      rv = rv[!rv[,id] %in% temp[,id],]
-      if(nrow(rv) == 0){return(rv)}
-    }
-    else{rv[which(is.element(rv$id,temp[,id])),"Set_Membership"] <- paste(rv[which(is.element(rv$id,temp[,id])),"Set_Membership"],tests[i], sep=" , ")}
   }
-  #Returning the master data frame.
-  return (rv)
+  # Returning the master data frame.
+  return(rv)
 }
 
 #' getEnrichmentsIntersection
@@ -216,48 +247,70 @@ getEnrichmentsIntersection <- function(
 #'
 #' @return a table
 #' @examples
-#'  getEnrichmentIntersection("No Pretreatment Timecourse Differential Phosphorylation", sigValue = c(.05),notTests=c(),annotation="GOSLIM",mustTests = c("IKE","FIN56"))
+#'  getEnrichmentIntersection(
+#'    "No Pretreatment Timecourse Differential Phosphorylation",
+#'    sigValue = c(.05),
+#'    notTests = c(),
+#'    annotation = "GOSLIM",
+#'    mustTests = c("IKE", "FIN56")
+#'  )
 #'
 #' Changes made to original function:
 #'   * Added arguments Enrichment.Results and Enrichment.Results.Adjusted
 #'   * Changed `<=` and `>=` to `<` and `>`, respectively, to match app UI
 #'
 #' @noRd
-getEnrichmentIntersection <- function(Enrichment.Results, Enrichment.Results.Adjusted, testCategory, mustTests, notTests, sigValue, annotation, operator=c("<"), pValType="nominal") {
-
+getEnrichmentIntersection <- function(
+  Enrichment.Results,
+  Enrichment.Results.Adjusted,
+  testCategory,
+  mustTests,
+  notTests,
+  sigValue,
+  annotation,
+  operator = c("<"),
+  pValType = "nominal"
+)
+{
   if (length(sigValue) != length(operator)) {
     stop("The arguments sigValue and operator must be the same length")
   }
 
-  #Generate Master Data Frame
-  if(pValType == "nominal"){
+  # Generate Master Data Frame
+  if (pValType == "nominal") {
     rv <- Enrichment.Results[[testCategory]][[annotation]]
     data <- Enrichment.Results[[testCategory]][[annotation]]
     tests <- names(Enrichment.Results[[testCategory]][[annotation]])
-  }else{
+  } else {
     rv <- Enrichment.Results.Adjusted[[testCategory]][[annotation]]
     data <- Enrichment.Results.Adjusted[[testCategory]][[annotation]]
     tests <- names(Enrichment.Results.Adjusted[[testCategory]][[annotation]])
   }
 
-  #Calculate Intersection
-  for(i in 2:length(tests)){
-    filteredColumn = data[,c(1,i)]
-    for(k in 1:length(operator)){
-      if(tests[i] %in% mustTests || tests[i] %in% notTests){
-        if(operator[k] == "<"){filteredColumn <- filteredColumn[filteredColumn[[tests[i]]] < sigValue[k],]}
-        else if(operator[k] == ">"){filteredColumn <- filteredColumn[filteredColumn[[tests[i]]] > sigValue[k],]}
+  # Calculate Intersection
+  for (i in 2:length(tests)) {
+    filteredColumn <- data[, c(1, i)]
+    for (k in 1:length(operator)) {
+      if (tests[i] %in% mustTests || tests[i] %in% notTests) {
+        if (operator[k] == "<") {
+          filteredColumn <- filteredColumn[filteredColumn[[tests[i]]] < sigValue[k], ]
+        } else if (operator[k] == ">") {
+          filteredColumn <- filteredColumn[filteredColumn[[tests[i]]] > sigValue[k], ]
+        }
       }
     }
-    if(tests[i] %in% mustTests){rv = rv[rv[,1] %in% filteredColumn[,1],]}
-    else if(tests[i] %in% notTests){rv = rv[!rv[,1] %in% filteredColumn[,1],]}
-    if(length(row.names(rv)) == 0){
+    if (tests[i] %in% mustTests) {
+      rv <- rv[rv[, 1] %in% filteredColumn[, 1], ]
+    } else if (tests[i] %in% notTests) {
+      rv <- rv[!rv[, 1] %in% filteredColumn[, 1], ]
+    }
+    if (length(row.names(rv)) == 0) {
       return(rv)
     }
   }
 
-  #Returning the master data frame.
-  return (rv)
+  # Returning the master data frame.
+  return(rv)
 }
 
 #' getResultsUpset
@@ -377,7 +430,12 @@ getResultsUpset <- function(
 #'
 #' @return An SVG
 #' @examples
-#'  InferenceUpsetPlot(testCategory = "No Pretreatment Timecourse Differential Phosphorylation", sigValue = c(.05), operator = c("<"), column = c("adj_P_Val"))
+#'  InferenceUpsetPlot(
+#'    testCategory = "No Pretreatment Timecourse Differential Phosphorylation",
+#'    sigValue = c(.05),
+#'    operator = c("<"),
+#'    column = c("adj_P_Val")
+#'  )
 #'
 #' Changes made to original function:
 #'   * Added Inference.Results as first argument
@@ -389,48 +447,68 @@ getResultsUpset <- function(
 #'   * Stop displaying empty intersections (due to poor performance with many sets)
 #'
 #' @noRd
-InferenceUpsetPlot <- function(Inference.Results, testCategory, sigValue, operator=c("<"), column= c("adj_P_Val")) {
-
+InferenceUpsetPlot <- function(
+  Inference.Results,
+  testCategory,
+  sigValue,
+  operator = c("<"),
+  column = c("adj_P_Val")
+)
+{
   if (length(sigValue) != length(operator) || length(column) != length(operator)) {
     stop("The arguments sigValue, column, and operator must be the same length")
   }
 
-  #Create list of variables from parameter strings
+  # Create list of variables from parameter strings
   tests <- names(Inference.Results[[testCategory]])
   testsUsed <- tests
-  # if("id_mult" %in% colnames(Inference.Results[[testCategory]][[tests[1]]])){id <- "id_mult"}
+  # if ("id_mult" %in% colnames(Inference.Results[[testCategory]][[tests[1]]])) {id <- "id_mult"}
   # else{id <- "id"}
   id <- colnames(Inference.Results[[testCategory]][[tests[1]]])[1]
 
-  #Create the master data frame
-  data <- data.frame(matrix(ncol=length(tests)+1, nrow=length(Inference.Results[[testCategory]][[tests[1]]][[id]])))
-  colnames(data) <- c("Identifier",tests)
-  data[,1] = as.character(Inference.Results[[testCategory]][[tests[1]]][[id]])
-  data = data[order(data[,1]),]
+  # Create the master data frame
+  data <- data.frame(
+    matrix(
+      ncol = length(tests) + 1,
+      nrow = length(Inference.Results[[testCategory]][[tests[1]]][[id]])
+    )
+  )
+  colnames(data) <- c("Identifier", tests)
+  data[, 1] = as.character(Inference.Results[[testCategory]][[tests[1]]][[id]])
+  data = data[order(data[, 1]), ]
 
-  for(i in 1:length(tests)){
+  for (i in 1:length(tests)) {
     mat <- Inference.Results[[testCategory]][[tests[i]]][[id]]
-    for(k in 1:length(operator)){
+    for (k in 1:length(operator)) {
       sigCol <- as.numeric(Inference.Results[[testCategory]][[tests[i]]][[column[k]]])
-      if(operator[k] == "<"){sigCol <- as.numeric(sigCol < sigValue[k])}
-      else if(operator[k] == ">"){sigCol <- as.numeric(sigCol > sigValue[k])}
-      else if(operator[k] == "|<|"){sigCol <- as.numeric(abs(sigCol) < sigValue[k])}
-      else if(operator[k] == "|>|"){sigCol <- as.numeric(abs(sigCol) > sigValue[k])}
-      if(sum(sigCol)==0){testsUsed <- testsUsed[testsUsed != tests[i]]}
+      if (operator[k] == "<") {
+        sigCol <- as.numeric(sigCol < sigValue[k])
+      } else if (operator[k] == ">") {
+        sigCol <- as.numeric(sigCol > sigValue[k])
+      } else if (operator[k] == "|<|") {
+        sigCol <- as.numeric(abs(sigCol) < sigValue[k])
+      } else if (operator[k] == "|>|") {
+        sigCol <- as.numeric(abs(sigCol) > sigValue[k])
+      }
+      if (sum(sigCol) == 0) {
+        testsUsed <- testsUsed[testsUsed != tests[i]]
+      }
       mat <- cbind.data.frame(mat, sigCol)
-      if(k > 1){
-        mat[,2] = as.integer(mat[,2] & mat[,3])
-        mat = mat[,-3]
+      if (k > 1) {
+        mat[, 2] <- as.integer(mat[, 2] & mat[, 3])
+        mat <- mat[, -3]
       }
     }
-    #This function assumes that all the tests have the same id_mults; therefore, we can order them so they are in the same order and match up when lined up.
-    #Each file must contain the same exact id_mults for this to work.
-    mat <- mat[order(mat[,1]),]
-    data[,i+1] <- as.numeric(mat[,2])
+    # This function assumes that all the tests have the same id_mults;
+    # therefore, we can order them so they are in the same order and match up
+    # when lined up. Each file must contain the same exact id_mults for this to
+    # work.
+    mat <- mat[order(mat[, 1]), ]
+    data[, i + 1] <- as.numeric(mat[, 2])
   }
-  if(length(testsUsed) <= 1){return (NULL)}
+  if (length(testsUsed) <= 1) {return(NULL)}
 
-  #Create the upset plot.
+  # Create the upset plot.
   rv <- UpSetR::upset(
     data,
     nintersects = 30,
@@ -439,7 +517,7 @@ InferenceUpsetPlot <- function(Inference.Results, testCategory, sigValue, operat
     order.by = "freq",
     empty.intersections = NULL
   )
-  #rv <- upset(data,point.size=1.1, line.size=0.4,sets = testsUsed, sets.bar.color = "#56B4E9",order.by = "freq", empty.intersections = "on")
+  #rv <- upset(data,point.size = 1.1, line.size = 0.4, sets = testsUsed, sets.bar.color = "#56B4E9", order.by = "freq", empty.intersections = "on")
   print(rv, newpage = FALSE)
   return(invisible(rv))
 }
@@ -504,7 +582,11 @@ getEnrichmentsUpset <- function(
 #'
 #' @return An SVG
 #' @examples
-#'  EnrichmentUpsetPlot("No Pretreatment Timecourse Differential Phosphorylation", annotation="GOSLIM",c(.05))
+#'  EnrichmentUpsetPlot(
+#'    "No Pretreatment Timecourse Differential Phosphorylation",
+#'    annotation = "GOSLIM",
+#'    c(.05)
+#'  )
 #'
 #' Changes made to original function:
 #'   * Added arguments Enrichment.Results and Enrichment.Results.Adjusted
@@ -517,49 +599,63 @@ getEnrichmentsUpset <- function(
 #'   * Stop displaying empty intersections (due to poor performance with many sets)
 #'
 #' @noRd
-EnrichmentUpsetPlot <- function(Enrichment.Results, Enrichment.Results.Adjusted, testCategory, annotation, sigValue, operator=c("<"), pValType="nominal", tests=NULL) {
-
+EnrichmentUpsetPlot <- function(
+  Enrichment.Results,
+  Enrichment.Results.Adjusted,
+  testCategory,
+  annotation,
+  sigValue,
+  operator = c("<"),
+  pValType = "nominal",
+  tests = NULL
+)
+{
   if (length(sigValue) != length(operator)) {
     stop("The arguments sigValue and operator must be the same length")
   }
-  if(!is.null(tests) && length(tests) < 2){
+  if (!is.null(tests) && length(tests) < 2) {
     stop("UpSet plot requires two or more tests to subset")
   }
 
-  if(pValType=="nominal"){
-    Identifier <- Enrichment.Results[[testCategory]][[annotation]][,1]
-    data <- Enrichment.Results[[testCategory]][[annotation]][,names(Enrichment.Results[[testCategory]][[annotation]])]
-  }else{
-    Identifier <- Enrichment.Results.Adjusted[[testCategory]][[annotation]][,1]
-    data <- Enrichment.Results.Adjusted[[testCategory]][[annotation]][,names(Enrichment.Results.Adjusted[[testCategory]][[annotation]])]
+  if (pValType == "nominal") {
+    Identifier <- Enrichment.Results[[testCategory]][[annotation]][, 1]
+    data <- Enrichment.Results[[testCategory]][[annotation]][, names(Enrichment.Results[[testCategory]][[annotation]])]
+  } else {
+    Identifier <- Enrichment.Results.Adjusted[[testCategory]][[annotation]][, 1]
+    data <- Enrichment.Results.Adjusted[[testCategory]][[annotation]][, names(Enrichment.Results.Adjusted[[testCategory]][[annotation]])]
   }
-  if(is.null(tests)){
+  if (is.null(tests)) {
     tests = colnames(data)
   }
 
-  for(i in 1:ncol(data)){
-    if(colnames(data)[i]%in%tests){
-      temp = data.frame(data[,1])
-      temp$newCol = 1
-      for(j in 1:length(operator)){
-        sigCol = data[,i]
-        if(operator[j]=="<"){sigCol <- as.numeric(sigCol < sigValue[j])}
-        else if(operator[j]==">"){sigCol <- as.numeric(sigCol > sigValue[j])}
-        temp = cbind(temp, sigCol)
-        temp[,2] = as.integer(temp[,2] & temp[,3])
-        temp = temp[,-3]
+  for (i in 1:ncol(data)) {
+    if (colnames(data)[i] %in% tests) {
+      temp <- data.frame(data[, 1])
+      temp$newCol <- 1
+      for (j in 1:length(operator)) {
+        sigCol <- data[, i]
+        if (operator[j] == "<") {
+          sigCol <- as.numeric(sigCol < sigValue[j])
+        } else if (operator[j] == ">") {
+          sigCol <- as.numeric(sigCol > sigValue[j])
+        }
+        temp <- cbind(temp, sigCol)
+        temp[, 2] <- as.integer(temp[, 2] & temp[, 3])
+        temp <- temp[, -3]
       }
-      if(sum(temp[,2], na.rm = TRUE) == 0){tests <- tests[tests != colnames(data)[i]]}
-      data[,i] = temp[,2]
+      if (sum(temp[, 2], na.rm = TRUE) == 0) {
+        tests <- tests[tests != colnames(data)[i]]
+      }
+      data[, i] <- temp[, 2]
     }
   }
-  if(length(tests) < 2){
+  if (length(tests) < 2) {
     stop("Not enough significant elements to create upset plot")
   }
 
   data <- cbind(Identifier, data)
 
-  #Create the upset plot.
+  # Create the upset plot.
   rv <- UpSetR::upset(
     data,
     nintersects = 30,
@@ -601,7 +697,7 @@ getUpsetCols <- function(
 {
   results <- getResults(study, modelID = modelID)
   if (isEmpty(results)) return(character())
-  colsAll <- lapply(results, function(x) colnames(x[, -1]))
+  colsAll <- lapply(results, function(x) colnames(x[, -1, drop = FALSE]))
   colsCommon <- Reduce(intersect, colsAll)
   return(colsCommon)
 }
